# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 14.0.0-beta.4
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RasterTileURL(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'url': 'str',
        'id_path': 'str',
        'min_z': 'int',
        'max_z': 'int',
        'check_geometry': 'bool'
    }

    attribute_map = {
        'url': 'url',
        'id_path': 'id_path',
        'min_z': 'min_z',
        'max_z': 'max_z',
        'check_geometry': 'check_geometry'
    }

    def __init__(self, url=None, id_path=None, min_z=None, max_z=None, check_geometry=None):  # noqa: E501
        """RasterTileURL - a model defined in Swagger"""  # noqa: E501

        self._url = None
        self._id_path = None
        self._min_z = None
        self._max_z = None
        self._check_geometry = None
        self.discriminator = None

        self.url = url
        self.id_path = id_path
        if min_z is not None:
            self.min_z = min_z
        if max_z is not None:
            self.max_z = max_z
        if check_geometry is not None:
            self.check_geometry = check_geometry

    @property
    def url(self):
        """Gets the url of this RasterTileURL.  # noqa: E501


        :return: The url of this RasterTileURL.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this RasterTileURL.


        :param url: The url of this RasterTileURL.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def id_path(self):
        """Gets the id_path of this RasterTileURL.  # noqa: E501


        :return: The id_path of this RasterTileURL.  # noqa: E501
        :rtype: str
        """
        return self._id_path

    @id_path.setter
    def id_path(self, id_path):
        """Sets the id_path of this RasterTileURL.


        :param id_path: The id_path of this RasterTileURL.  # noqa: E501
        :type: str
        """
        if id_path is None:
            raise ValueError("Invalid value for `id_path`, must not be `None`")  # noqa: E501

        self._id_path = id_path

    @property
    def min_z(self):
        """Gets the min_z of this RasterTileURL.  # noqa: E501


        :return: The min_z of this RasterTileURL.  # noqa: E501
        :rtype: int
        """
        return self._min_z

    @min_z.setter
    def min_z(self, min_z):
        """Sets the min_z of this RasterTileURL.


        :param min_z: The min_z of this RasterTileURL.  # noqa: E501
        :type: int
        """

        self._min_z = min_z

    @property
    def max_z(self):
        """Gets the max_z of this RasterTileURL.  # noqa: E501


        :return: The max_z of this RasterTileURL.  # noqa: E501
        :rtype: int
        """
        return self._max_z

    @max_z.setter
    def max_z(self, max_z):
        """Sets the max_z of this RasterTileURL.


        :param max_z: The max_z of this RasterTileURL.  # noqa: E501
        :type: int
        """

        self._max_z = max_z

    @property
    def check_geometry(self):
        """Gets the check_geometry of this RasterTileURL.  # noqa: E501


        :return: The check_geometry of this RasterTileURL.  # noqa: E501
        :rtype: bool
        """
        return self._check_geometry

    @check_geometry.setter
    def check_geometry(self, check_geometry):
        """Sets the check_geometry of this RasterTileURL.


        :param check_geometry: The check_geometry of this RasterTileURL.  # noqa: E501
        :type: bool
        """

        self._check_geometry = check_geometry

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RasterTileURL):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 14.0.0-beta.4
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from arlas_api_python.api_client import ApiClient


class CollectionsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete(self, collection, **kwargs):  # noqa: E501
        """Delete a collection reference  # noqa: E501

        Delete a collection reference in ARLAS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete(collection, async=True)
        >>> result = thread.get()

        :param async bool
        :param str collection: collection (required)
        :param bool pretty: Pretty print
        :return: Success
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_with_http_info(collection, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_with_http_info(collection, **kwargs)  # noqa: E501
            return data

    def delete_with_http_info(self, collection, **kwargs):  # noqa: E501
        """Delete a collection reference  # noqa: E501

        Delete a collection reference in ARLAS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_with_http_info(collection, async=True)
        >>> result = thread.get()

        :param async bool
        :param str collection: collection (required)
        :param bool pretty: Pretty print
        :return: Success
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['collection', 'pretty']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'collection' is set
        if ('collection' not in params or
                params['collection'] is None):
            raise ValueError("Missing the required parameter `collection` when calling `delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'collection' in params:
            path_params['collection'] = params['collection']  # noqa: E501

        query_params = []
        if 'pretty' in params:
            query_params.append(('pretty', params['pretty']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=utf-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/collections/{collection}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Success',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_collections(self, **kwargs):  # noqa: E501
        """Get all collection references as a json file  # noqa: E501

        Get all collection references in ARLAS as json file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.export_collections(async=True)
        >>> result = thread.get()

        :param async bool
        :return: list[CollectionReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.export_collections_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.export_collections_with_http_info(**kwargs)  # noqa: E501
            return data

    def export_collections_with_http_info(self, **kwargs):  # noqa: E501
        """Get all collection references as a json file  # noqa: E501

        Get all collection references in ARLAS as json file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.export_collections_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :return: list[CollectionReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_collections" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=utf-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/collections/_export', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CollectionReference]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get(self, collection, **kwargs):  # noqa: E501
        """Get a collection reference  # noqa: E501

        Get a collection reference in ARLAS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get(collection, async=True)
        >>> result = thread.get()

        :param async bool
        :param str collection: collection (required)
        :param bool pretty: Pretty print
        :return: CollectionReference
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_with_http_info(collection, **kwargs)  # noqa: E501
        else:
            (data) = self.get_with_http_info(collection, **kwargs)  # noqa: E501
            return data

    def get_with_http_info(self, collection, **kwargs):  # noqa: E501
        """Get a collection reference  # noqa: E501

        Get a collection reference in ARLAS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_with_http_info(collection, async=True)
        >>> result = thread.get()

        :param async bool
        :param str collection: collection (required)
        :param bool pretty: Pretty print
        :return: CollectionReference
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['collection', 'pretty']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'collection' is set
        if ('collection' not in params or
                params['collection'] is None):
            raise ValueError("Missing the required parameter `collection` when calling `get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'collection' in params:
            path_params['collection'] = params['collection']  # noqa: E501

        query_params = []
        if 'pretty' in params:
            query_params.append(('pretty', params['pretty']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=utf-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/collections/{collection}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CollectionReference',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all(self, **kwargs):  # noqa: E501
        """Get all collection references  # noqa: E501

        Get all collection references in ARLAS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_all(async=True)
        >>> result = thread.get()

        :param async bool
        :param bool pretty: Pretty print
        :return: list[CollectionReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_all_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_with_http_info(self, **kwargs):  # noqa: E501
        """Get all collection references  # noqa: E501

        Get all collection references in ARLAS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_all_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param bool pretty: Pretty print
        :return: list[CollectionReference]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pretty']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pretty' in params:
            query_params.append(('pretty', params['pretty']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=utf-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/collections', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CollectionReference]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def import_collections(self, **kwargs):  # noqa: E501
        """Add collection references from a json file  # noqa: E501

        Add collection references in ARLAS from a json file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.import_collections(async=True)
        >>> result = thread.get()

        :param async bool
        :param file file:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.import_collections_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.import_collections_with_http_info(**kwargs)  # noqa: E501
            return data

    def import_collections_with_http_info(self, **kwargs):  # noqa: E501
        """Add collection references from a json file  # noqa: E501

        Add collection references in ARLAS from a json file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.import_collections_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param file file:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_collections" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/collections/_import', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put(self, collection, collection_params, **kwargs):  # noqa: E501
        """Add a collection reference  # noqa: E501

        Add a collection reference in ARLAS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.put(collection, collection_params, async=True)
        >>> result = thread.get()

        :param async bool
        :param str collection: collection (required)
        :param CollectionReferenceParameters collection_params: collectionParams (required)
        :param bool pretty: Pretty print
        :return: CollectionReference
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.put_with_http_info(collection, collection_params, **kwargs)  # noqa: E501
        else:
            (data) = self.put_with_http_info(collection, collection_params, **kwargs)  # noqa: E501
            return data

    def put_with_http_info(self, collection, collection_params, **kwargs):  # noqa: E501
        """Add a collection reference  # noqa: E501

        Add a collection reference in ARLAS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.put_with_http_info(collection, collection_params, async=True)
        >>> result = thread.get()

        :param async bool
        :param str collection: collection (required)
        :param CollectionReferenceParameters collection_params: collectionParams (required)
        :param bool pretty: Pretty print
        :return: CollectionReference
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['collection', 'collection_params', 'pretty']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'collection' is set
        if ('collection' not in params or
                params['collection'] is None):
            raise ValueError("Missing the required parameter `collection` when calling `put`")  # noqa: E501
        # verify the required parameter 'collection_params' is set
        if ('collection_params' not in params or
                params['collection_params'] is None):
            raise ValueError("Missing the required parameter `collection_params` when calling `put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'collection' in params:
            path_params['collection'] = params['collection']  # noqa: E501

        query_params = []
        if 'pretty' in params:
            query_params.append(('pretty', params['pretty']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'collection_params' in params:
            body_params = params['collection_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=utf-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/collections/{collection}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CollectionReference',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 14.0.0-beta.4
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Page(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'size': 'int',
        '_from': 'int',
        'sort': 'str',
        'after': 'str',
        'before': 'str'
    }

    attribute_map = {
        'size': 'size',
        '_from': 'from',
        'sort': 'sort',
        'after': 'after',
        'before': 'before'
    }

    def __init__(self, size=None, _from=None, sort=None, after=None, before=None):  # noqa: E501
        """Page - a model defined in Swagger"""  # noqa: E501

        self._size = None
        self.__from = None
        self._sort = None
        self._after = None
        self._before = None
        self.discriminator = None

        if size is not None:
            self.size = size
        if _from is not None:
            self._from = _from
        if sort is not None:
            self.sort = sort
        if after is not None:
            self.after = after
        if before is not None:
            self.before = before

    @property
    def size(self):
        """Gets the size of this Page.  # noqa: E501


        :return: The size of this Page.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Page.


        :param size: The size of this Page.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def _from(self):
        """Gets the _from of this Page.  # noqa: E501


        :return: The _from of this Page.  # noqa: E501
        :rtype: int
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this Page.


        :param _from: The _from of this Page.  # noqa: E501
        :type: int
        """

        self.__from = _from

    @property
    def sort(self):
        """Gets the sort of this Page.  # noqa: E501


        :return: The sort of this Page.  # noqa: E501
        :rtype: str
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this Page.


        :param sort: The sort of this Page.  # noqa: E501
        :type: str
        """

        self._sort = sort

    @property
    def after(self):
        """Gets the after of this Page.  # noqa: E501


        :return: The after of this Page.  # noqa: E501
        :rtype: str
        """
        return self._after

    @after.setter
    def after(self, after):
        """Sets the after of this Page.


        :param after: The after of this Page.  # noqa: E501
        :type: str
        """

        self._after = after

    @property
    def before(self):
        """Gets the before of this Page.  # noqa: E501


        :return: The before of this Page.  # noqa: E501
        :rtype: str
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this Page.


        :param before: The before of this Page.  # noqa: E501
        :type: str
        """

        self._before = before

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Page):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 14.0.0-beta.4
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class OpenSearch(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'short_name': 'str',
        'description': 'str',
        'contact': 'str',
        'tags': 'str',
        'long_name': 'str',
        'image_height': 'str',
        'image_width': 'str',
        'image_type': 'str',
        'image_url': 'str',
        'developer': 'str',
        'attribution': 'str',
        'syndication_right': 'str',
        'adult_content': 'str',
        'language': 'str',
        'input_encoding': 'str',
        'output_encoding': 'str'
    }

    attribute_map = {
        'short_name': 'short_name',
        'description': 'description',
        'contact': 'contact',
        'tags': 'tags',
        'long_name': 'long_name',
        'image_height': 'image_height',
        'image_width': 'image_width',
        'image_type': 'image_type',
        'image_url': 'image_url',
        'developer': 'developer',
        'attribution': 'attribution',
        'syndication_right': 'syndication_right',
        'adult_content': 'adult_content',
        'language': 'language',
        'input_encoding': 'input_encoding',
        'output_encoding': 'output_encoding'
    }

    def __init__(self, short_name=None, description=None, contact=None, tags=None, long_name=None, image_height=None, image_width=None, image_type=None, image_url=None, developer=None, attribution=None, syndication_right=None, adult_content=None, language=None, input_encoding=None, output_encoding=None):  # noqa: E501
        """OpenSearch - a model defined in Swagger"""  # noqa: E501

        self._short_name = None
        self._description = None
        self._contact = None
        self._tags = None
        self._long_name = None
        self._image_height = None
        self._image_width = None
        self._image_type = None
        self._image_url = None
        self._developer = None
        self._attribution = None
        self._syndication_right = None
        self._adult_content = None
        self._language = None
        self._input_encoding = None
        self._output_encoding = None
        self.discriminator = None

        if short_name is not None:
            self.short_name = short_name
        if description is not None:
            self.description = description
        if contact is not None:
            self.contact = contact
        if tags is not None:
            self.tags = tags
        if long_name is not None:
            self.long_name = long_name
        if image_height is not None:
            self.image_height = image_height
        if image_width is not None:
            self.image_width = image_width
        if image_type is not None:
            self.image_type = image_type
        if image_url is not None:
            self.image_url = image_url
        if developer is not None:
            self.developer = developer
        if attribution is not None:
            self.attribution = attribution
        if syndication_right is not None:
            self.syndication_right = syndication_right
        if adult_content is not None:
            self.adult_content = adult_content
        if language is not None:
            self.language = language
        if input_encoding is not None:
            self.input_encoding = input_encoding
        if output_encoding is not None:
            self.output_encoding = output_encoding

    @property
    def short_name(self):
        """Gets the short_name of this OpenSearch.  # noqa: E501


        :return: The short_name of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._short_name

    @short_name.setter
    def short_name(self, short_name):
        """Sets the short_name of this OpenSearch.


        :param short_name: The short_name of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._short_name = short_name

    @property
    def description(self):
        """Gets the description of this OpenSearch.  # noqa: E501


        :return: The description of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this OpenSearch.


        :param description: The description of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def contact(self):
        """Gets the contact of this OpenSearch.  # noqa: E501


        :return: The contact of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """Sets the contact of this OpenSearch.


        :param contact: The contact of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._contact = contact

    @property
    def tags(self):
        """Gets the tags of this OpenSearch.  # noqa: E501


        :return: The tags of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this OpenSearch.


        :param tags: The tags of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._tags = tags

    @property
    def long_name(self):
        """Gets the long_name of this OpenSearch.  # noqa: E501


        :return: The long_name of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._long_name

    @long_name.setter
    def long_name(self, long_name):
        """Sets the long_name of this OpenSearch.


        :param long_name: The long_name of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._long_name = long_name

    @property
    def image_height(self):
        """Gets the image_height of this OpenSearch.  # noqa: E501


        :return: The image_height of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._image_height

    @image_height.setter
    def image_height(self, image_height):
        """Sets the image_height of this OpenSearch.


        :param image_height: The image_height of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._image_height = image_height

    @property
    def image_width(self):
        """Gets the image_width of this OpenSearch.  # noqa: E501


        :return: The image_width of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._image_width

    @image_width.setter
    def image_width(self, image_width):
        """Sets the image_width of this OpenSearch.


        :param image_width: The image_width of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._image_width = image_width

    @property
    def image_type(self):
        """Gets the image_type of this OpenSearch.  # noqa: E501


        :return: The image_type of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._image_type

    @image_type.setter
    def image_type(self, image_type):
        """Sets the image_type of this OpenSearch.


        :param image_type: The image_type of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._image_type = image_type

    @property
    def image_url(self):
        """Gets the image_url of this OpenSearch.  # noqa: E501


        :return: The image_url of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """Sets the image_url of this OpenSearch.


        :param image_url: The image_url of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._image_url = image_url

    @property
    def developer(self):
        """Gets the developer of this OpenSearch.  # noqa: E501


        :return: The developer of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._developer

    @developer.setter
    def developer(self, developer):
        """Sets the developer of this OpenSearch.


        :param developer: The developer of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._developer = developer

    @property
    def attribution(self):
        """Gets the attribution of this OpenSearch.  # noqa: E501


        :return: The attribution of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._attribution

    @attribution.setter
    def attribution(self, attribution):
        """Sets the attribution of this OpenSearch.


        :param attribution: The attribution of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._attribution = attribution

    @property
    def syndication_right(self):
        """Gets the syndication_right of this OpenSearch.  # noqa: E501


        :return: The syndication_right of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._syndication_right

    @syndication_right.setter
    def syndication_right(self, syndication_right):
        """Sets the syndication_right of this OpenSearch.


        :param syndication_right: The syndication_right of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._syndication_right = syndication_right

    @property
    def adult_content(self):
        """Gets the adult_content of this OpenSearch.  # noqa: E501


        :return: The adult_content of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._adult_content

    @adult_content.setter
    def adult_content(self, adult_content):
        """Sets the adult_content of this OpenSearch.


        :param adult_content: The adult_content of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._adult_content = adult_content

    @property
    def language(self):
        """Gets the language of this OpenSearch.  # noqa: E501


        :return: The language of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this OpenSearch.


        :param language: The language of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def input_encoding(self):
        """Gets the input_encoding of this OpenSearch.  # noqa: E501


        :return: The input_encoding of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._input_encoding

    @input_encoding.setter
    def input_encoding(self, input_encoding):
        """Sets the input_encoding of this OpenSearch.


        :param input_encoding: The input_encoding of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._input_encoding = input_encoding

    @property
    def output_encoding(self):
        """Gets the output_encoding of this OpenSearch.  # noqa: E501


        :return: The output_encoding of this OpenSearch.  # noqa: E501
        :rtype: str
        """
        return self._output_encoding

    @output_encoding.setter
    def output_encoding(self, output_encoding):
        """Sets the output_encoding of this OpenSearch.


        :param output_encoding: The output_encoding of this OpenSearch.  # noqa: E501
        :type: str
        """

        self._output_encoding = output_encoding

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OpenSearch):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 14.0.0-beta.4
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import arlas_api_python
from arlas_api_python.api.collections_api import CollectionsApi  # noqa: E501
from arlas_api_python.rest import ApiException


class TestCollectionsApi(unittest.TestCase):
    """CollectionsApi unit test stubs"""

    def setUp(self):
        self.api = arlas_api_python.api.collections_api.CollectionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete(self):
        """Test case for delete

        Delete a collection reference  # noqa: E501
        """
        pass

    def test_export_collections(self):
        """Test case for export_collections

        Get all collection references as a json file  # noqa: E501
        """
        pass

    def test_get(self):
        """Test case for get

        Get a collection reference  # noqa: E501
        """
        pass

    def test_get_all(self):
        """Test case for get_all

        Get all collection references  # noqa: E501
        """
        pass

    def test_import_collections(self):
        """Test case for import_collections

        Add collection references from a json file  # noqa: E501
        """
        pass

    def test_put(self):
        """Test case for put

        Add a collection reference  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
